@@ -9,5 +9,7 @@ from .cli import (
     make_cli,
     run_cli,
     setvars,
+    with_extras,
 )
 from .config import ConfigFile, config, register_extension
+from .version import version
